@@ -57,9 +57,10 @@ class ConfigParserProgram(object):
         "cache_dir": "cache",
         "cache_expiry": CachedObject.DEFAULT_EXPIRY,
 
-        "bgpq3_path": "bgpq3",
+        "bgpq3_path": "bgpq4",
         "bgpq3_host": IRRDBInfo.BGPQ3_DEFAULT_HOST,
         "bgpq3_sources": IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
+        "bgpq3_timeout": IRRDBInfo.BGPQ3_DEFAULT_TIMEOUT,
 
         "rtt_getter_path": "",
 
@@ -127,6 +128,10 @@ class ConfigParserProgram(object):
         else:
             self.cfg["cfg_dir"] = os.path.dirname(os.path.expanduser(path))
 
+        if isinstance(self.cfg["bgpq3_host"], str):
+            list_as_str = self.cfg["bgpq3_host"]
+            self.cfg["bgpq3_host"] = list(map(str.strip, list_as_str.split(",")))
+
         # relative path -> absolute path
         for cfg_key in self.PATH_KEYS:
             if not self.cfg[cfg_key]:
